aboutsummaryrefslogtreecommitdiffstats
path: root/oni-core.el
diff options
context:
space:
mode:
authorGravatar Tom Willemse2021-06-21 23:03:56 -0700
committerGravatar Tom Willemse2021-06-21 23:03:56 -0700
commite6ea0611eec945b0822fd976853ab035d5f17c8e (patch)
tree5f302bf06cc6ef7dc85d2fd875ed355a13a591c0 /oni-core.el
parent2609dbab87a187238f145ec0a1a2d8c276a78106 (diff)
downloademacs-config-e6ea0611eec945b0822fd976853ab035d5f17c8e.tar.gz
emacs-config-e6ea0611eec945b0822fd976853ab035d5f17c8e.zip
[oni-core] Add dashboard
Diffstat (limited to 'oni-core.el')
-rw-r--r--oni-core.el12
1 files changed, 5 insertions, 7 deletions
diff --git a/oni-core.el b/oni-core.el
index 0ce6bc8..1e60b34 100644
--- a/oni-core.el
+++ b/oni-core.el
@@ -4,8 +4,8 @@
;; Author: Tom Willemse <tom@ryuslash.org>
;; Keywords: local
;; Version: 2021.0425.175742
;; Package-Requires: (oni-data-dir oni-embrace oni-hydra expand-region multiple-cursors gcmh diminish ws-butler which-key insert-char-preview)
;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
@@ -145,11 +145,9 @@ _s_: String list"
(setq electric-pair-skip-whitespace 'chomp)
(setq fit-window-to-buffer-horizontally t)
-(setq initial-major-mode 'org-mode)
-(setq initial-scratch-message "# This buffer is for text that is not saved.
-# To create a file, visit it with [[help:find-file][find-file]] and enter text in its buffer.
-
-")
+(require 'dashboard)
+(dashboard-setup-startup-hook)
+(setq initial-buffer-choice (lambda () (get-buffer "*dashboard*")))
;; Increase the threshold for garbage collection for increased performance.
;; Apparently there are some (lsp-mode for example) packages that generate a lot
@@ -4,8 +4,8 @@
;; Author: Tom Willemse <tom@ryuslash.org>
;; Keywords: local
-;; Version: 2021.0425.175742
-;; Package-Requires: (oni-data-dir oni-embrace oni-hydra expand-region multiple-cursors gcmh diminish ws-butler which-key insert-char-preview)
+;; Version: 2021.0621.230313
+;; Package-Requires: (oni-data-dir oni-embrace oni-hydra expand-region multiple-cursors gcmh diminish ws-butler which-key insert-char-preview dashboard)
;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by